%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}

%{!?_initddir: %global _initddir %{_initrddir}}

%if 0%{?fedora} >= 17
%global with_systemd 1
%endif

%global major 2.2

Name:           trytond
Version:        2.2.6
Release:        1%{?dist}
Summary:        Server for the Tryton application framework

Group:          System Environment/Daemons
License:        GPLv3+
URL:            http://www.tryton.org
Source0:        http://downloads.tryton.org/%{major}/%{name}-%{version}.tar.gz
Source10:       %{name}.init
Source11:       %{name}.sysconfig
Source20:       %{name}.service

BuildArch:      noarch
BuildRequires:  python2-devel
BuildRequires:  python-setuptools
BuildRequires:  python-sphinx
%if 0%{?with_systemd}
BuildRequires:  systemd-units
%endif

Requires:       %{name}-server = %{version}-%{release}
Requires:       python-lxml
Requires:       python-relatorio
Requires:       mx
Requires:       pydot
Requires:       pytz
Requires:       pyOpenSSL
Requires:       python-dateutil
Requires:       python-polib
Requires(pre):  shadow-utils
%if 0%{?with_systemd}
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
%else
Requires(post):  chkconfig
Requires(preun): chkconfig
Requires(preun): initscripts
Requires(postun): initscripts
%endif

Provides:       tryton(kernel) = %{major}


%description
Tryton is a three-tiers high-level general purpose application framework
written in Python and use PostgreSQL as database engine. It is the core base
of an Open Source ERP. It provides modularity, scalability and security.

The core of Tryton (also called Tryton kernel) provides all the necessary
functionalities for a complete application framework: data persistence (i.e
an ORM with extensive modularity), users management (authentication, fine
grained control for data access, handling of concurrent access of resources),
workflow and report engines, web services and internationalisation. Thus
constituting a complete application platform which can be used for any
relevant purpose.


%package openoffice
Summary:        OpenOffice.org support for Tryton Server
Group:          System Environment/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       python-openoffice
%if 0%{?rhel}
ExcludeArch:    ppc
%endif

%description openoffice
OpenOffice.org support for Tryton Server.


%package webdav
Summary:        WebDAV support for Tryton Server
Group:          System Environment/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       pywebdav

%description webdav
WebDAV support for Tryton Server.


%package mysql
Summary:        MySQL support for Tryton Server
Group:          System Environment/Libraries
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-server = %{version}-%{release}
Requires:       MySQL-python

%description mysql
MySQL support for Tryton Server.


%package pgsql
Summary:        PostgreSQL support for Tryton Server
Group:          System Environment/Libraries
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-server = %{version}-%{release}
Requires:       python-psycopg2

%description pgsql
PostgreSQL support for Tryton Server.


%package sqlite
Summary:        SQLite support for Tryton Server
Group:          System Environment/Libraries
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-server = %{version}-%{release}
%if 0%{?rhel} && 0%{?rhel} <= 5
Requires:       python-sqlite2
%endif

%description sqlite
SQLite support for Tryton Server.


%prep
%setup -q

# remove the shebang line
sed -i -e '1d' trytond/tests/test_tryton.py


%build
%{__python} setup.py build

# docs
pushd doc
make html
popd


%install
%{__python} setup.py install --skip-build --root $RPM_BUILD_ROOT

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}
install -p -m 640 etc/%{name}.conf $RPM_BUILD_ROOT%{_sysconfdir}

%if 0%{?with_systemd}
mkdir -p $RPM_BUILD_ROOT%{_unitdir}
install -p -m 644 %{SOURCE20} $RPM_BUILD_ROOT%{_unitdir}/
%else
mkdir -p $RPM_BUILD_ROOT%{_initddir}
install -p -m 755 %{SOURCE10} $RPM_BUILD_ROOT%{_initddir}/%{name}

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig
install -p -m 644 %{SOURCE11} $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/%{name}
%endif

mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/{lib,log}/%{name}


%pre
getent group tryton > /dev/null || /usr/sbin/groupadd -r tryton
getent passwd tryton > /dev/null || /usr/sbin/useradd -r -g tryton \
       -d %{_localstatedir}/lib/%{name} -s /sbin/nologin tryton
:

%if 0%{?with_systemd}
%post
if [ $1 -eq 1 ] ; then
	# Initial installation
	/bin/systemctl daemon-reload >/dev/null 2>&1 || :
fi

%preun
if [ $1 -eq 0 ] ; then
	# Package removal, not upgrade
	/bin/systemctl --no-reload disable trytond.service > /dev/null 2>&1 || :
	/bin/systemctl stop trytond.service > /dev/null 2>&1 || :
fi

%postun
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ $1 -ge 1 ] ; then
	# Package upgrade, not uninstall
	/bin/systemctl try-restart trytond.service >/dev/null 2>&1 || :
fi
%else
%post
/sbin/chkconfig --add %{name} || :

%preun
if [ "$1" -eq 0 ]; then
	/sbin/service %{name} stop &> /dev/null
	/sbin/chkconfig --del %{name}
fi
:

%postun
if [ "$1" -ge 1 ]; then
	/sbin/service %{name} condrestart &> /dev/null || :
fi
%endif


%files
%doc CHANGELOG COPYRIGHT INSTALL LICENSE README TODO
%doc doc/_build/html
%if 0%{?with_systemd}
%{_unitdir}/%{name}.service
%else
%{_initddir}/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%endif
%attr(0640,tryton,tryton) %config(noreplace) %{_sysconfdir}/%{name}.conf
%{_bindir}/%{name}
%{python_sitelib}/*
%exclude %{python_sitelib}/%{name}/backend/mysql
%exclude %{python_sitelib}/%{name}/backend/postgresql
%exclude %{python_sitelib}/%{name}/backend/sqlite
%attr(0750,tryton,tryton) %{_localstatedir}/lib/%{name}
%attr(0750,tryton,tryton) %{_localstatedir}/log/%{name}

%files openoffice

%files webdav

%files mysql
%{python_sitelib}/%{name}/backend/mysql

%files pgsql
%{python_sitelib}/%{name}/backend/postgresql

%files sqlite
%{python_sitelib}/%{name}/backend/sqlite


%changelog
* Fri Jan 04 2013 Dan Horák <dan@danny.cz> - 2.2.6-1
- new upstream version 2.2.6

* Wed Jun 13 2012 Dan Horák <dan@danny.cz> - 2.2.3-2
- convert from initscript to systemd unit and use the unit file for Fedora >= 17

* Sat Jun 02 2012 Dan Horák <dan@danny.cz> - 2.2.3-1
- new upstream version 2.2.3

* Fri Mar 30 2012 Dan Horák <dan@danny.cz> - 2.2.2-1
- new upstream version 2.2.2 (CVE-2012-0215)

* Mon Mar 05 2012 Dan Horák <dan@danny.cz> - 2.2.1-3
- add missing R:

* Wed Feb  8 2012 Toshio Kuratomi <toshio@fedoraproject.org> - 2.2.1-2
- Remove the python-sqlite2 dep in Fedora as tryton will work with sqlite3 from
  the python stdlib

* Sun Jan 15 2012 Dan Horák <dan@danny.cz> - 2.2.1-1
- new upstream version 2.2.1

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sun Oct 23 2011 Dan Horák <dan@danny.cz> - 2.0.2-1
- new upstream version 2.0.2

* Mon Jun 06 2011 Dan Horák <dan@danny.cz> - 2.0.1-1
- new upstream version 2.0.1

* Tue May 03 2011 Dan Horák <dan@danny.cz> - 2.0.0-1
- new upstream version 2.0.0

* Mon Feb 21 2011 Dan Horák <dan[at]danny.cz> 1.8.2-1
- update to upstream version 1.8.2

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Nov 17 2010 Dan Horák <dan[at]danny.cz> 1.8.1-2
- drop the conflicts between db backends, they can co-exist

* Tue Nov 16 2010 Dan Horák <dan[at]danny.cz> 1.8.1-1.1
- fix the tryton(kernel) Provides:

* Sat Nov 13 2010 Dan Horák <dan[at]danny.cz> 1.8.1-1
- update to upstream version 1.8.1

* Sat Nov 13 2010 Dan Horák <dan[at]danny.cz> 1.6.2-1
- update to upstream version 1.6.2
- do not duplicate the logs on console (#641609)

* Thu Jul 22 2010 David Malcolm <dmalcolm@redhat.com> - 1.6.0-4
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Thu Jul 15 2010 Dan Horák <dan[at]danny.cz> 1.6.0-3
- build documentation
- add R: python-dateutil

* Wed Jul  7 2010 Dan Horák <dan[at]danny.cz> 1.6.0-2
- fix the tryton(kernel) Provides:

* Wed Jul  7 2010 Dan Horák <dan[at]danny.cz> 1.6.0-1
- update to upstream version 1.6.0
- split the DB support into subpackages

* Thu Apr  1 2010 Dan Horák <dan[at]danny.cz> 1.4.5-1
- update to upstream version 1.4.5

* Fri Feb 19 2010 Dan Horák <dan[at]danny.cz> 1.4.4-1
- update to upstream version 1.4.4

* Thu Dec 10 2009 Dan Horák <dan[at]danny.cz> 1.4.3-1
- update to upstream version 1.4.3

* Sat Nov 28 2009 Dan Horák <dan[at]danny.cz> 1.4.2-1
- update to upstream version 1.4.2

* Wed Oct 21 2009 Dan Horák <dan[at]danny.cz> 1.4.1-1
- update to upstream version 1.4.1

* Mon Aug 31 2009 Dan Horák <dan[at]danny.cz> 1.2.2-1
- update to upstream version 1.2.2

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Jul 10 2009 Dan Horák <dan[at]danny.cz> 1.2.1-1
- update to upstream version 1.2.1

* Fri May 22 2009 Dan Horák <dan[at]danny.cz> 1.2.0-1
- update to upstream version 1.2.0

* Fri Mar  6 2009 Dan Horák <dan[at]danny.cz> 1.0.3-1
- update to upstream version 1.0.3

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Jan 21 2009 Dan Horák <dan[at]danny.cz> 1.0.2-2
- add modular support for webdav

* Thu Jan  8 2009 Dan Horák <dan[at]danny.cz> 1.0.2-1
- modularize the openoffice.org support
- update to upstream version 1.0.2

* Tue Dec  2 2008 Dan Horák <dan[at]danny.cz> 1.0.1-2
- add dependency on python-openoffice

* Mon Dec  1 2008 Dan Horák <dan[at]danny.cz> 1.0.1-1
- update to upstream version 1.0.1

* Fri Nov 28 2008 Dan Horák <dan[at]danny.cz> 1.0.0-2
- keep modules in %%python_sitelib after a discussion with upstream, user
  written and non packaged modules will be symlinked there

* Fri Nov 28 2008 Dan Horák <dan[at]danny.cz> 1.0.0-1
- initial Fedora version
